@@ -7,6 +7,6 @@ class EventWriter:
     def __init__(self, logger: Logger):
         self._logger = logger
 
-    def write_event(self, event: CloudEvent):
+    def write_event(self, event: CloudEvent) -> None:
         self._logger.info("sending event")
         self._logger.info(event)
