@@ -2,14 +2,11 @@ from helix_events_sdk.schemas.audit_enums import AuditAction, AuditActionType, R
 
 
 class Audit:
-    def __init__(self,
-                 patient_id: str,
-                 user_id: str,
-                 user_role: str,
-                 ip_address: str,
-                 action: AuditAction,
-                 action_type: AuditActionType,
-                 accessed_resource: ResourceType):
+    def __init__(
+        self, patient_id: str, user_id: str, user_role: str, ip_address: str,
+        action: AuditAction, action_type: AuditActionType,
+        accessed_resource: ResourceType
+    ):
         self.patient_id = patient_id
         self.user_id = user_id
         self.action = action.value
@@ -18,6 +15,3 @@ class Audit:
         self.action_type = action_type.value
         self.source_system = "b.well"
         self.document_type = accessed_resource.value
-
-
-
