@@ -8,19 +8,25 @@ from helix_events_sdk.schemas.audit_enums import AuditAction, AuditActionType, R
 from helix_events_sdk.schemas.source import Source
 
 
-def test_can_send_event(caplog):
+def test_can_send_event(caplog) -> None:  # type: ignore
     caplog.set_level(INFO)
-    event = AuditEvent(Source.BWELLBACKEND, Audit(patient_id="1",
-                                                  user_id="1",
-                                                  user_role="Patient",
-                                                  ip_address="192.168.1.1",
-                                                  action=AuditAction.READ,
-                                                  action_type=AuditActionType.VIEW,
-                                                  accessed_resource=ResourceType.DIAGNOSES))
+    event = AuditEvent(
+        Source.BWELLBACKEND,
+        Audit(
+            patient_id="1",
+            user_id="1",
+            user_role="Patient",
+            ip_address="192.168.1.1",
+            action=AuditAction.READ,
+            action_type=AuditActionType.VIEW,
+            accessed_resource=ResourceType.DIAGNOSES
+        )
+    )
 
     event_writer = EventWriter(get_logger())
     event_writer.write_event(event=event)
 
+
 def get_logger() -> Logger:
     logger = getLogger(__name__)
     stream_handler: StreamHandler = StreamHandler(stdout)
